@@ -12,7 +12,14 @@ from cve_bin_tool.checkers import Checker
 
 
 class BindChecker(Checker):
-    CONTAINS_PATTERNS = []
+    CONTAINS_PATTERNS = [
+        r"bind9_check_key",
+        r"bind9_check_namedconf",
+        # r"/bind9.xsl",
+    ]
     FILENAME_PATTERNS = [r"named"]
-    VERSION_PATTERNS = [r"BIND ([0-9]+\.[0-9]+\.[0-9]+)"]
+    VERSION_PATTERNS = [
+        r"BIND ([0-9]+\.[0-9]+\.[0-9]+)",  # for .rpm, .tgz, etc.
+        r"bind[0-9]-([0-9]+\.[0-9]+\.[0-9]+)",  # for .deb
+    ]
     VENDOR_PRODUCT = [("isc", "bind")]
