@@ -12,7 +12,7 @@ from cve_bin_tool.checkers import Checker
 
 
 class CryptsetupChecker(Checker):
-    CONTAIN_PATTERNS = [
+    CONTAINS_PATTERNS = [
         r"Legacy offline reencryption already in-progress. Use cryptsetup-reencrypt utility.",
         r"Only LUKS2 format is currently supported. Please use cryptsetup-reencrypt tool for LUKS1.",
     ]
