@@ -17,8 +17,15 @@ from cve_bin_tool.checkers import Checker
 
 
 class CurlChecker(Checker):
-    # FIXME: fix contains pattern
-    CONTAINS_PATTERNS = []
+    CONTAINS_PATTERNS = [
+        r"Dump libcurl equivalent code of this command line",
+        r"a specified protocol is unsupported by libcurl",
+        # r"curl failed to verify the legitimacy of the server and therefore could not",
+        # r"error retrieving curl library information",
+        # r"ignoring --proxy-capath, not supported by libcurl",
+    ]
     FILENAME_PATTERNS = [r"curl"]
-    VERSION_PATTERNS = [r"curl ([678]+\.[0-9]+\.[0-9]+)"]
-    VENDOR_PRODUCT = [("haxx", "curl")]
+    VERSION_PATTERNS = [
+        r"curl ([678]+\.[0-9]+\.[0-9]+)",
+    ]
+    VENDOR_PRODUCT = [("haxx", "curl"), ("haxx", "libcurl")]
