@@ -12,7 +12,9 @@ from cve_bin_tool.checkers import Checker
 
 class DnsmasqChecker(Checker):
     CONTAINS_PATTERNS = [
-        r"Dnsmasq is lightweight, easy to configure DNS forwarder and DHCP server\.\neither in each host or in a central configuration file\."
+        r"Dnsmasq is free software, and you are welcome to redistribute it",
+        # r"Allow access only to files owned by the user running dnsmasq\.",
+        # r"Display dnsmasq version and copyright information\.",
     ]
     FILENAME_PATTERNS = [r"dnsmasq"]
     VERSION_PATTERNS = [r"dnsmasq-([0-9]+\.[0-9]+)"]
