@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for haproxy
@@ -6,7 +8,7 @@ CVE checker for haproxy
 https://www.cvedetails.com/product/22372/Haproxy-Haproxy.html?vendor_id=11969
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class HaproxyChecker(Checker):
