@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for hostapd
@@ -6,7 +8,7 @@ CVE checker for hostapd
 https://www.cvedetails.com/product/22495/W1.fi-Hostapd.html?vendor_id=12005
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class HostapdChecker(Checker):
