@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for libtiff
@@ -7,7 +9,7 @@ http://www.cvedetails.com/vulnerability-list/vendor_id-2224/product_id-3881/Libt
 
 RSS feed: http://www.cvedetails.com/vulnerability-feed.php?vendor_id=2224&product_id=3881&version_id=&orderby=3&cvssscoremin=0
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class LibtiffChecker(Checker):
