@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for netpbm
@@ -6,7 +8,7 @@ CVE checker for netpbm
 https://www.cvedetails.com/product/2877/Netpbm-Netpbm.html?vendor_id=1666
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class NetpbmChecker(Checker):
