@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for node.js
@@ -8,7 +10,7 @@ http://www.cvedetails.com/vulnerability-list/vendor_id-12113/Nodejs.html
 
 RSS feed: http://www.cvedetails.com/vulnerability-feed.php?vendor_id=12113&product_id=0&version_id=&orderby=3&cvssscoremin=0
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class NodeChecker(Checker):
