@@ -12,7 +12,10 @@ from cve_bin_tool.checkers import Checker
 
 
 class WiresharkChecker(Checker):
-    CONTAINS_PATTERNS = []
-    FILENAME_PATTERNS = [r"rawshark"]
+    CONTAINS_PATTERNS = [
+        r"'usermod -a -G wireshark _your_username_' as root.",
+        r"Are you a member of the 'wireshark' group\? Try running",
+    ]
+    FILENAME_PATTERNS = [r"rawshark", r"wireshark"]
     VERSION_PATTERNS = [r"Wireshark ([0-9]+\.[0-9]+\.[0-9]+)"]
     VENDOR_PRODUCT = [("wireshark", "wireshark")]
