@@ -1,15 +1,15 @@
 # Copyright (C) 2021 Intel Corporation
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-#!/usr/bin/python3
-# pylint: disable=invalid-name
 
 """
 This tool scans for a number of common, vulnerable open source components
 (openssl, libpng, libxml2, expat and a few others) to let you know if your
 system includes common libraries with known vulnerabilities.  It emits a list
-of CVE numbers that may be relevant to your binary based on the versions.  It
-cannot detect backported fixes.
+of CVE numbers that may be relevant to your binary based on the versions.
+There is a flag to enable information about backported fixes for specific
+Linux distributions, but cve-bin-tool cannot detect backported fixes outside
+of those published lists.
 """
 
 import argparse
@@ -23,6 +23,11 @@ from typing import Dict
 
 import pkg_resources
 
+from cve_bin_tool.available_fix import (
+    AvailableFixReport,
+    get_available_fix_supported_distros,
+    get_backport_supported_distros,
+)
 from cve_bin_tool.config import ConfigParser
 from cve_bin_tool.cve_scanner import CVEScanner
 from cve_bin_tool.cvedb import CVEDB, OLD_CACHE_DIR
@@ -39,6 +44,7 @@ from cve_bin_tool.log import LOGGER
 from cve_bin_tool.merge import MergeReports
 from cve_bin_tool.output_engine import OutputEngine
 from cve_bin_tool.package_list_parser import PackageListParser
+from cve_bin_tool.sbom_manager import SBOMManager
 from cve_bin_tool.util import ProductInfo
 from cve_bin_tool.version import VERSION
 from cve_bin_tool.version_scanner import VersionScanner
@@ -75,18 +81,29 @@ def main(argv=None):
         + "\n\nPlease disclose issues responsibly!",
         formatter_class=argparse.RawDescriptionHelpFormatter,
     )
+
+    nvd_database_group = parser.add_argument_group(
+        "CVE Data Download", "Arguments related to NVD Database and Cache Configuration"
+    )
+    nvd_database_group.add_argument(
+        "-n",
+        "--nvd",
+        action="store",
+        choices=["api", "json"],
+        help="choose method for getting CVE lists from NVD",
+    )
+    nvd_database_group.add_argument(
+        "-u",
+        "--update",
+        action="store",
+        choices=["now", "daily", "never", "latest"],
+        help="update schedule for NVD database (default: daily)",
+    )
+
     input_group = parser.add_argument_group("Input")
     input_group.add_argument(
         "directory", help="directory to scan", nargs="?", default=None
     )
-    input_group.add_argument(
-        "-e",
-        "--exclude",
-        action=StringToListAction,
-        help="Comma separated Exclude directory path",
-        default=None,
-    )
-
     input_group.add_argument(
         "-i",
         "--input-file",
@@ -100,6 +117,18 @@ def main(argv=None):
     input_group.add_argument(
         "-L", "--package-list", action="store", default="", help="provide package list"
     )
+    input_group.add_argument(
+        "--sbom",
+        action="store",
+        default="spdx",
+        choices=["spdx", "cyclonedx", "swid"],
+        help="specify type of software bill of materials (sbom) (default: spdx)",
+    )
+    input_group.add_argument(
+        "--sbom-file",
+        action="store",
+        help="provide sbom filename",
+    )
 
     output_group = parser.add_argument_group("Output")
     output_group.add_argument(
@@ -150,43 +179,74 @@ def main(argv=None):
         help="Produces a report even if there are no CVE for the respective output format",
     )
     output_group.add_argument(
+        "-A",
+        "--available-fix",
+        action="store",
+        nargs="?",
+        const="local",
+        choices=get_available_fix_supported_distros(),
+        metavar="<distro_name>-<distro_version_name>",
+        help="Lists available fixes of the package from Linux distribution",
+    )
+    output_group.add_argument(
+        "-b",
+        "--backport-fix",
+        action="store",
+        nargs="?",
+        const="local",
+        choices=get_backport_supported_distros(),
+        metavar="<distro_name>-<distro_version_name>",
+        help="Lists backported fixes if available from Linux distribution",
+    )
+    output_group.add_argument(
+        "--affected-versions",
+        action="count",
+        default=0,
+        help="Lists versions of product affected by a given CVE (to facilitate upgrades)",
+    )
+
+    parser.add_argument(
+        "-e",
+        "--exclude",
+        action=StringToListAction,
+        help="Comma separated Exclude directory path",
+        default=None,
+    )
+    parser.add_argument("-V", "--version", action="version", version=VERSION)
+    parser.add_argument(
+        "--disable-version-check",
+        action="store_true",
+        help="skips checking for a new version",
+    )
+
+    merge_report_group = parser.add_argument_group(
+        "Merge Report", "Arguments related to Intermediate and Merged Reports"
+    )
+    merge_report_group.add_argument(
         "-a",
         "--append",
         nargs="?",
         const=True,
         help="save output as intermediate report in json format",
     )
-    output_group.add_argument(
+    merge_report_group.add_argument(
         "-t",
         "--tag",
         action="store",
         help="add a unique tag to differentiate between multiple intermediate reports",
     )
-    parser.add_argument("-V", "--version", action="version", version=VERSION)
-    parser.add_argument(
-        "-u",
-        "--update",
-        action="store",
-        choices=["now", "daily", "never", "latest"],
-        help="update schedule for NVD database (default: daily)",
-    )
-    parser.add_argument(
-        "-x",
-        "--extract",
-        action="store_true",
-        help="autoextract compressed files",
-    )
-    parser.add_argument(
-        "--disable-version-check",
-        action="store_true",
-        help="skips checking for a new version",
-    )
-    parser.add_argument(
+    merge_report_group.add_argument(
         "-m",
         "--merge",
         action=StringToListAction,
         help="comma separated intermediate reports path for merging",
     )
+    merge_report_group.add_argument(
+        "-F",
+        "--filter",
+        action=StringToListAction,
+        help="comma separated tag string for filtering intermediate reports",
+    )
 
     checker_group = parser.add_argument_group("Checkers")
     checker_group.add_argument(
@@ -205,6 +265,15 @@ def main(argv=None):
         type=str,
         help="comma-separated list of checkers to enable",
     )
+
+    deprecated_group = parser.add_argument_group("Deprecated")
+    deprecated_group.add_argument(
+        "-x",
+        "--extract",
+        action="store_true",
+        help="autoextract compressed files",
+    )
+
     defaults = {
         "directory": "",
         "exclude": [],
@@ -226,6 +295,13 @@ def main(argv=None):
         "append": False,
         "tag": "",
         "merge": None,
+        "backport_fix": "",
+        "available_fix": "",
+        "nvd": "api",
+        "filter": [],
+        "affected_versions": 0,
+        "sbom": "spdx",
+        "sbom_file": "",
     }
 
     with ErrorHandler(mode=ErrorMode.NoTrace):
@@ -277,18 +353,29 @@ def main(argv=None):
         LOGGER.info(
             "You can use -f --format and -o --output-file for saving merged intermediate reports in a file"
         )
-        merged_reports = MergeReports(merge_files=args["merge"], score=score)
+        merged_reports = MergeReports(
+            merge_files=args["merge"], score=score, filter_tag=args["filter"]
+        )
         if args["input_file"]:
             LOGGER.warning(
                 "Ignoring -i --input-file while merging intermediate reports"
             )
             args["input_file"] = None
         merge_cve_scanner = merged_reports.merge_intermediate()
+    elif args["filter"] and not args["merge"]:
+        LOGGER.warning(
+            "Use -F --filter only when you want to filter out intermediate reports on the basis of tag"
+        )
 
     # Database update related settings
     # Connect to the database
     cvedb_orig = CVEDB(
-        version_check=not args["disable_version_check"], error_mode=error_mode
+        version_check=not args["disable_version_check"],
+        error_mode=error_mode,
+        nvd_type=args["nvd"],
+        incremental_update=True
+        if args["update"] == "latest" and args["nvd"]
+        else False,
     )
 
     # if OLD_CACHE_DIR (from cvedb.py) exists, print warning
@@ -308,11 +395,12 @@ def main(argv=None):
     if args["update"] != "never":
         cvedb_orig.get_cvelist_if_stale()
     else:
-        LOGGER.warning("Not verifying CVE DB cache")
-        cvedb_orig.get_db_update_date()
-        if not cvedb_orig.nvd_years():
-            with ErrorHandler(mode=error_mode, logger=LOGGER):
-                raise EmptyCache(cvedb_orig.cachedir)
+        if args["nvd"] == "json":
+            LOGGER.warning("Not verifying CVE DB cache")
+            cvedb_orig.get_db_update_date()
+            if not cvedb_orig.nvd_years():
+                with ErrorHandler(mode=error_mode, logger=LOGGER):
+                    raise EmptyCache(cvedb_orig.cachedir)
 
     # CVE Database validation
     if not cvedb_orig.check_cve_entries():
@@ -327,6 +415,7 @@ def main(argv=None):
         and not args["input_file"]
         and not args["package_list"]
         and not args["merge"]
+        and not args["sbom_file"]
     ):
         parser.print_usage()
         with ErrorHandler(logger=LOGGER, mode=ErrorMode.NoTrace):
@@ -337,7 +426,7 @@ def main(argv=None):
     # Output validation
     if not args["append"] and args["tag"]:
         LOGGER.warning(
-            f"Please specify -a --append to generate intermediate reports while using -t --tag"
+            "Please specify -a --append to generate intermediate reports while using -t --tag"
         )
 
     if args["directory"] and not os.path.exists(args["directory"]):
@@ -371,7 +460,7 @@ def main(argv=None):
             )
             parsed_data = package_list.parse_list()
             for product_info, triage_data in parsed_data.items():
-                LOGGER.warning(f"{product_info}, {triage_data}")
+                LOGGER.debug(f"{product_info}, {triage_data}")
                 cve_scanner.get_cves(product_info, triage_data)
 
         if args["input_file"]:
@@ -381,7 +470,7 @@ def main(argv=None):
             parsed_data = input_engine.parse_input()
             if not args["directory"]:
                 for product_info, triage_data in parsed_data.items():
-                    LOGGER.warning(f"{product_info}, {triage_data}")
+                    LOGGER.debug(f"{product_info}, {triage_data}")
                     cve_scanner.get_cves(product_info, triage_data)
         if args["directory"]:
             version_scanner = VersionScanner(
@@ -390,6 +479,7 @@ def main(argv=None):
                 error_mode=error_mode,
             )
             version_scanner.remove_skiplist(skips)
+            LOGGER.info(f"Number of checkers: {version_scanner.number_of_checkers()}")
             version_scanner.print_checkers()
             for scan_info in version_scanner.recursive_scan(args["directory"]):
                 if scan_info:
@@ -404,9 +494,22 @@ def main(argv=None):
         if args["merge"]:
             cve_scanner = merge_cve_scanner
 
+        if args["sbom_file"]:
+            # Process SBOM file
+            sbom_list = SBOMManager(
+                args["sbom_file"], sbom_type=args["sbom"], logger=LOGGER
+            )
+            parsed_data = sbom_list.scan_file()
+            LOGGER.info(
+                f"The number of products to process from SBOM - {len(parsed_data)}"
+            )
+            for product_info, triage_data in parsed_data.items():
+                LOGGER.debug(f"{product_info}, {triage_data}")
+                cve_scanner.get_cves(product_info, triage_data)
+
         LOGGER.info("")
         LOGGER.info("Overall CVE summary: ")
-        if args["input_file"] or args["package_list"]:
+        if args["input_file"] or args["package_list"] or args["sbom_file"]:
             LOGGER.info(
                 f"There are {cve_scanner.products_with_cve} products with known CVEs detected"
             )
@@ -426,6 +529,7 @@ def main(argv=None):
             # Creates a Object for OutputEngine
             output = OutputEngine(
                 all_cve_data=cve_scanner.all_cve_data,
+                all_cve_version_info=cve_scanner.all_cve_version_info,
                 scanned_dir=args["directory"],
                 filename=args["output_file"],
                 themes_dir=args["html_theme"],
@@ -437,15 +541,32 @@ def main(argv=None):
                 is_report=args["report"],
                 append=args["append"],
                 merge_report=merged_reports,
+                affected_versions=args["affected_versions"],
             )
 
             if not args["quiet"]:
                 output.output_file(args["format"])
+                if args["backport_fix"] or args["available_fix"]:
+                    distro_info = args["backport_fix"] or args["available_fix"]
+                    is_backport = True if args["backport_fix"] else False
+                    fixes = AvailableFixReport(
+                        cve_scanner.all_cve_data, distro_info, is_backport
+                    )
+                    fixes.check_available_fix()
 
-        # Use the number of products with known cves as error code
-        # as requested by folk planning to automate use of this script.
-        # If no cves found, then the program exits cleanly.
-        return cve_scanner.products_with_cve
+        # If no cves found, then the program exits cleanly (0 exit)
+        if cve_scanner.products_with_cve == 0:
+            return 0
+
+        # if some cves are found, return with exit code 1
+        # Previously this returned a number of CVEs found, but that can
+        # exceed expected return value range.
+        if cve_scanner.products_with_cve > 0:
+            return 1
+
+        # If somehow we got negative numbers of cves something has gone
+        # horribly wrong.  Since return code 2 is used by argparse, use 3
+        return 3
 
 
 if __name__ == "__main__":
