@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 import os
+import re
 import sqlite3
 import sys
 from collections import defaultdict
@@ -10,17 +11,14 @@ from string import ascii_lowercase
 from typing import DefaultDict, Dict, List
 
 from pkg_resources import parse_version
-from rich.columns import Columns
 from rich.console import Console
-from rich.panel import Panel
 
 from cve_bin_tool.cvedb import DBNAME, DISK_LOCATION_DEFAULT
 from cve_bin_tool.error_handler import ErrorMode
 from cve_bin_tool.input_engine import TriageData
-from cve_bin_tool.linkify import linkify_cve
 from cve_bin_tool.log import LOGGER
 from cve_bin_tool.theme import cve_theme
-from cve_bin_tool.util import CVE, CVEData, ProductInfo
+from cve_bin_tool.util import CVE, CVEData, ProductInfo, VersionInfo
 
 
 class CVEScanner:
@@ -31,6 +29,7 @@ class CVEScanner:
     products_with_cve: int
     products_without_cve: int
     all_cve_data: DefaultDict[ProductInfo, CVEData]
+    all_cve_version_info: Dict[str, VersionInfo]
 
     RANGE_UNSET: str = ""
     dbname: str = os.path.join(DISK_LOCATION_DEFAULT, DBNAME)
@@ -49,6 +48,7 @@ class CVEScanner:
         self.products_with_cve = 0
         self.products_without_cve = 0
         self.all_cve_data = defaultdict(CVEData)
+        self.all_cve_version_info = dict()
 
     def get_cves(self, product_info: ProductInfo, triage_data: TriageData):
         """Get CVEs against a specific version of a product.
@@ -56,6 +56,9 @@ class CVEScanner:
         Example:
             nvd.get_cves('haxx', 'curl', '7.34.0')
         """
+        if product_info.vendor == "UNKNOWN":
+            return
+
         if product_info in self.all_cve_data:
             # If product_info already in all_cve_data no need to fetch cves from database again
             # We just need to update paths.
@@ -70,7 +73,23 @@ class CVEScanner:
         """
         # Removing * from vendors that are guessed by the package list parser
         vendor = product_info.vendor.replace("*", "")
-        self.cursor.execute(query, [vendor, product_info.product, product_info.version])
+
+        # Need to manipulate version to ensure canonical form of version
+        if product_info.product == "openssl":
+            pv = re.search(r"\d[.\d]*[a-z]?", product_info.version)
+            parsed_version_between = parse_version(self.openssl_convert(pv.group(0)))
+        else:
+            # Ensure canonical form of version numbering
+            if ":" in product_info.version:
+                # Handle x:a.b<string> e.g. 2:7.4+23
+                components = product_info.version.split(":")
+                pv = re.search(r"\d[.\d]*", components[1])
+            else:
+                # Handle a.b.c<string> e.g. 1.20.9rel1
+                pv = re.search(r"\d[.\d]*", product_info.version)
+        parsed_version = parse_version(pv.group(0))
+
+        self.cursor.execute(query, [vendor, product_info.product, str(parsed_version)])
 
         cve_list = list(map(lambda x: x[0], self.cursor.fetchall()))
 
@@ -86,50 +105,45 @@ class CVEScanner:
         WHERE vendor=? AND product=? AND version=?
         """
 
-        # Removing * from vendors that are guessed by the package list parser
-        vendor = product_info.vendor.replace("*", "")
         self.cursor.execute(query, [vendor, product_info.product, "*"])
 
         for cve_range in self.cursor:
             (
                 cve_number,
-                versionStartIncluding,
-                versionStartExcluding,
-                versionEndIncluding,
-                versionEndExcluding,
+                version_start_including,
+                version_start_excluding,
+                version_end_including,
+                version_end_excluding,
             ) = cve_range
 
-            parsed_version = parse_version(product_info.version)
-
             # pep-440 doesn't include versions of the type 1.1.0g used by openssl
             # so if this is openssl, convert the last letter to a .number
             if product_info.product == "openssl":
                 # if last character is a letter, convert it to .number
                 # version = self.openssl_convert(product_info.version)
-                versionStartIncluding = self.openssl_convert(versionStartIncluding)
-                versionStartExcluding = self.openssl_convert(versionStartExcluding)
-                versionEndIncluding = self.openssl_convert(versionEndIncluding)
-                versionEndExcluding = self.openssl_convert(versionEndExcluding)
-                parsed_version = parse_version(
-                    self.openssl_convert(product_info.version)
-                )
+                version_start_including = self.openssl_convert(version_start_including)
+                version_start_excluding = self.openssl_convert(version_start_excluding)
+                version_end_including = self.openssl_convert(version_end_including)
+                version_end_excluding = self.openssl_convert(version_end_excluding)
+                parsed_version = parsed_version_between
 
             # check the start range
             passes_start = False
             if (
-                versionStartIncluding is not self.RANGE_UNSET
-                and parsed_version >= parse_version(versionStartIncluding)
-            ):
-                passes_start = True
-            if (
-                versionStartExcluding is not self.RANGE_UNSET
-                and parsed_version > parse_version(versionStartExcluding)
+                version_start_including is not self.RANGE_UNSET
+                and parsed_version >= parse_version(version_start_including)
             ):
                 passes_start = True
 
             if (
-                versionStartIncluding is self.RANGE_UNSET
-                and versionStartExcluding is self.RANGE_UNSET
+                version_start_excluding is not self.RANGE_UNSET
+                and parsed_version > parse_version(version_start_excluding)
+            ):
+                passes_start = True
+
+            if (
+                version_start_including is self.RANGE_UNSET
+                and version_start_excluding is self.RANGE_UNSET
             ):
                 # then there is no start range so just say true
                 passes_start = True
@@ -137,83 +151,87 @@ class CVEScanner:
             # check the end range
             passes_end = False
             if (
-                versionEndIncluding is not self.RANGE_UNSET
-                and parsed_version <= parse_version(versionEndIncluding)
+                version_end_including is not self.RANGE_UNSET
+                and parsed_version <= parse_version(version_end_including)
             ):
                 passes_end = True
 
             if (
-                versionEndExcluding is not self.RANGE_UNSET
-                and parsed_version < parse_version(versionEndExcluding)
+                version_end_excluding is not self.RANGE_UNSET
+                and parsed_version < parse_version(version_end_excluding)
             ):
                 passes_end = True
+
             if (
-                versionEndIncluding is self.RANGE_UNSET
-                and versionEndExcluding is self.RANGE_UNSET
+                version_end_including is self.RANGE_UNSET
+                and version_end_excluding is self.RANGE_UNSET
             ):
                 # then there is no end range so it passes
                 passes_end = True
             # if it fits into both ends of the range, add the cve number
             if passes_start and passes_end:
                 cve_list.append(cve_number)
+                self.all_cve_version_info[cve_number] = VersionInfo(
+                    start_including=version_start_including,
+                    start_excluding=version_start_excluding,
+                    end_including=version_end_including,
+                    end_excluding=version_end_excluding,
+                )
 
         # Go through and get all the severities
         if cve_list:
-            query = f"""
-            SELECT CVE_number, severity, description, score, cvss_version
-            FROM cve_severity
-            WHERE CVE_number IN ({",".join(["?"] * len(cve_list))}) AND score >= ?
-            ORDER BY CVE_number
-            """
-            # Add score parameter to tuple listing CVEs to pass to query
-            cve_list.append(self.score)
-
-            result = self.cursor.execute(query, cve_list)
 
             cves: List[CVE] = []
-            for row in result:
-                triage = triage_data.get(row["cve_number"]) or triage_data.get(
-                    "default"
-                )
-                # Only scan cves if triage is not None.
-                # Triage will only be None if triage_data don't have default attribute.
-                # NOTE: Triage can be empty dictionary so checking `if triage:` won't suffice.
-                if triage is not None:
-                    row_dict = dict(row)
-                    row_dict.update(triage)
-                    # print(row_dict)
-                    row_dict["severity"] = row_dict["severity"] or row["severity"]
-                    row_dict["score"] = row_dict["score"] or row["score"]
-                    row_dict["cvss_version"] = (
-                        row_dict["cvss_version"] or row["cvss_version"]
+            finished = False
+            max_cves = 500
+            remaining = len(cve_list)
+            start = 0
+
+            while not finished:
+                # Limit number of CVEs in single query to maximum
+                number_of_cves = min(remaining, max_cves)
+                end = start + number_of_cves
+                remaining = remaining - number_of_cves
+                finished = remaining == 0
+
+                query = f"""
+                SELECT CVE_number, severity, description, score, cvss_version, cvss_vector
+                FROM cve_severity
+                WHERE CVE_number IN ({",".join(["?"] * number_of_cves)}) AND score >= ?
+                ORDER BY CVE_number
+                """
+                # Add score parameter to tuple listing CVEs to pass to query
+                result = self.cursor.execute(query, cve_list[start:end] + [self.score])
+                start = end
+
+                for row in result:
+                    triage = triage_data.get(row["cve_number"]) or triage_data.get(
+                        "default"
                     )
-                    cve = CVE(**row_dict)
-                    cves.append(cve)
+                    # Only scan cves if triage is not None.
+                    # Triage will only be None if triage_data don't have default attribute.
+                    # NOTE: Triage can be empty dictionary so checking `if triage:` won't suffice.
+                    if triage is not None:
+                        row_dict = dict(row)
+                        row_dict.update(triage)
+                        # print(row_dict)
+                        row_dict["severity"] = row_dict["severity"] or row["severity"]
+                        row_dict["score"] = row_dict["score"] or row["score"]
+                        row_dict["cvss_version"] = (
+                            row_dict["cvss_version"] or row["cvss_version"]
+                        )
+                        cve = CVE(**row_dict)
+                        cves.append(cve)
 
             if cves:
                 self.products_with_cve += 1
-                self.logger.info(f"Known CVEs in {product_info}")
+                self.logger.debug(f"Known CVEs in {product_info}")
+
                 # error_mode.value will only be greater than 1 if quiet mode.
                 if self.error_mode.value > 1:
-                    title = f"[default][b]{len(cves)}[/b] CVE(s) in [b]{product_info.vendor}.{product_info.product}[/b] v[b]{product_info.version}[/b]"
-                    self.CONSOLE.log()
-                    self.CONSOLE.log(
-                        Panel(
-                            Columns(
-                                (
-                                    linkify_cve(
-                                        f"[{cve.severity.lower()}]{cve.cve_number}"
-                                    )
-                                    for cve in cves
-                                ),
-                                padding=(0, 2),
-                            ),
-                            padding=1,
-                            border_style="red",
-                            title=title,
-                        )
+                    self.logger.info(
+                        f"{len(cves)} CVE(s) in {product_info.vendor}.{product_info.product} v{product_info.version}"
                     )
-                    self.CONSOLE.log()
             else:
                 # No cves found for (product, vendor, version) tuple in the NVD database.
                 self.products_without_cve += 1
@@ -227,7 +245,6 @@ class CVEScanner:
             self.logger.debug(
                 f"No CVEs found for {product_info}. Is the vendor/product info correct?"
             )
-            self.all_cve_data[product_info]["cves"] = [CVE("UNKNOWN", "UNKNOWN")]
 
     def openssl_convert(self, version: str) -> str:
         """pkg_resources follows pep-440 which doesn't expect openssl style 1.1.0g version numbering
