@@ -31,17 +31,19 @@ from cve_bin_tool.error_handler import (
     SHAMismatch,
 )
 from cve_bin_tool.log import LOGGER
-from cve_bin_tool.version import check_latest_version
+from cve_bin_tool.nvd_api import NVD_API
+from cve_bin_tool.version import VERSION, check_latest_version
 
 logging.basicConfig(level=logging.DEBUG)
 
 # database defaults
+DISK_LOCATION_DEFAULT = os.path.join(os.path.expanduser("~"), ".cache", "cve-bin-tool")
 DISK_LOCATION_BACKUP = os.path.join(
     os.path.expanduser("~"), ".cache", "cve-bin-tool-backup"
 )
-DISK_LOCATION_DEFAULT = os.path.join(os.path.expanduser("~"), ".cache", "cve-bin-tool")
 DBNAME = "cve.db"
 OLD_CACHE_DIR = os.path.join(os.path.expanduser("~"), ".cache", "cvedb")
+NVD_FILENAME_TEMPLATE = "nvdcve-1.1-{}.json.gz"
 
 
 class CVEDB:
@@ -53,7 +55,7 @@ class CVEDB:
     BACKUPCACHEDIR = DISK_LOCATION_BACKUP
     FEED = "https://nvd.nist.gov/vuln/data-feeds"
     LOGGER = LOGGER.getChild("CVEDB")
-    NVDCVE_FILENAME_TEMPLATE = "nvdcve-1.1-{}.json.gz"
+    NVDCVE_FILENAME_TEMPLATE = NVD_FILENAME_TEMPLATE
     CURL_CVE_FILENAME_TEMPLATE = "curlcve-{}.json"
     META_LINK = "https://nvd.nist.gov"
     META_REGEX = re.compile(r"\/feeds\/json\/.*-[0-9]*\.[0-9]*-[0-9]*\.meta")
@@ -67,6 +69,8 @@ class CVEDB:
         version_check=True,
         session=None,
         error_mode=ErrorMode.TruncTrace,
+        nvd_type="json",
+        incremental_update=False,
     ):
         self.feed = feed if feed is not None else self.FEED
         self.cachedir = cachedir if cachedir is not None else self.CACHEDIR
@@ -85,6 +89,9 @@ class CVEDB:
         self.connection = None
         self.session = session
         self.cve_count = -1
+        self.nvd_type = nvd_type
+        self.incremental_update = incremental_update
+        self.all_cve_entries = None
 
         if not os.path.exists(self.dbpath):
             self.rollback_cache_backup()
@@ -95,6 +102,26 @@ class CVEDB:
             self.check_cve_entries()
         return self.cve_count
 
+    async def nist_fetch_using_api(self):
+        """Fetch using NVD's CVE API (as opposed to NVD's JSON Vulnerability Feeds)"""
+        nvd_api = NVD_API(
+            logger=self.LOGGER,
+            error_mode=self.error_mode,
+            incremental_update=self.incremental_update,
+        )
+        if self.incremental_update:
+            await nvd_api.get_nvd_params(
+                time_of_last_update=datetime.datetime.fromtimestamp(
+                    self.get_db_update_date()
+                )
+            )
+        else:
+            await nvd_api.get_nvd_params()
+        await nvd_api.get()
+        await nvd_api.session.close()
+        nvd_api.session = None
+        return nvd_api.all_cve_entries
+
     def get_db_update_date(self):
         # last time when CVE data was updated
         self.time_of_last_update = datetime.datetime.fromtimestamp(
@@ -154,7 +181,7 @@ class CVEDB:
             gotsha = calculate.hexdigest().upper()
             if gotsha != sha:
                 os.unlink(filepath)
-                self.LOGGER.warning(
+                self.LOGGER.debug(
                     f"SHA mismatch for {filename} (have: {gotsha}, want: {sha})"
                 )
             else:
@@ -226,25 +253,37 @@ class CVEDB:
         # refresh the database
         if not os.path.isdir(self.cachedir):
             os.makedirs(self.cachedir)
+        self.LOGGER.info(f"CVE Binary Tool v{VERSION}")
         # check for the latest version
         if self.version_check:
-            self.LOGGER.info("Checking if there is a newer version.")
             check_latest_version()
         if not self.session:
             connector = aiohttp.TCPConnector(limit_per_host=19)
             self.session = RateLimiter(
                 aiohttp.ClientSession(connector=connector, trust_env=True)
             )
-        self.LOGGER.info("Downloading CVE data...")
-        nvd_metadata, curl_metadata = await asyncio.gather(
-            asyncio.ensure_future(self.nist_scrape(self.session)),
-            asyncio.ensure_future(self.get_curl_versions(self.session)),
-        )
-        tasks = [
-            asyncio.ensure_future(self.cache_update(self.session, url, meta["sha256"]))
-            for url, meta in nvd_metadata.items()
-            if meta is not None
-        ]
+
+        tasks = []
+        if self.nvd_type == "api":
+            self.LOGGER.info("[Using NVD API]")
+            self.all_cve_entries, curl_metadata = await asyncio.gather(
+                self.nist_fetch_using_api(),
+                self.get_curl_versions(self.session),
+            )
+
+        else:
+            self.LOGGER.info("Downloading CVE data...")
+            nvd_metadata, curl_metadata = await asyncio.gather(
+                self.nist_scrape(self.session),
+                self.get_curl_versions(self.session),
+            )
+
+            tasks = [
+                self.cache_update(self.session, url, meta["sha256"])
+                for url, meta in nvd_metadata.items()
+                if meta is not None
+            ]
+
         # We use gather to create a single task from a set of tasks
         # which download CVEs for each version of curl. Otherwise
         # the progress bar would show that we are closer to
@@ -279,7 +318,7 @@ class CVEDB:
         self.session = None
 
     def refresh_cache_and_update_db(self):
-        self.LOGGER.info("Updating CVE data. This will take a few minutes.")
+        self.LOGGER.debug("Updating CVE data. This will take a few minutes.")
         # refresh the nvd cache
         run_coroutine(self.refresh())
 
@@ -304,16 +343,22 @@ class CVEDB:
             self.LOGGER.info(
                 "Using cached CVE data (<24h old). Use -u now to update immediately."
             )
+            self.db_open()
+            if not self.latest_schema(self.connection.cursor()):
+                self.refresh_cache_and_update_db()
+                self.time_of_last_update = datetime.datetime.today()
+            else:
+                self.db_close()
 
     def latest_schema(self, cursor):
         """Check database is using latest schema"""
-        self.LOGGER.info("Check database is using latest schema")
+        self.LOGGER.debug("Check database is using latest schema")
         schema_check = "SELECT * FROM cve_severity WHERE 1=0"
         result = cursor.execute(schema_check)
         schema_latest = False
         # Look through column names and check for column added in latest schema
         for col_name in result.description:
-            if col_name[0] == "description":
+            if col_name[0] == "cvss_vector":
                 schema_latest = True
         return schema_latest
 
@@ -341,6 +386,7 @@ class CVEDB:
             description TEXT,
             score INTEGER,
             cvss_version INTEGER,
+            cvss_vector TEXT,
             PRIMARY KEY(cve_number)
         )
         """
@@ -387,9 +433,10 @@ class CVEDB:
             severity,
             description,
             score,
-            cvss_version
+            cvss_version,
+            cvss_vector
         )
-        VALUES (?, ?, ?, ?, ?)
+        VALUES (?, ?, ?, ?, ?, ?)
         """
         insert_cve_range = """
         INSERT or REPLACE INTO cve_range(
@@ -404,102 +451,131 @@ class CVEDB:
         ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)
         """
         del_cve_range = "DELETE from cve_range where CVE_number=?"
-
-        # error_mode.value will only be greater than 1 if quiet mode.
-        if self.error_mode.value > 1:
-            years = track(self.nvd_years(), description="Updating CVEs from NVD...")
-        else:
-            years = self.nvd_years()
-
-        for year in years:
-            cve_data = self.load_nvd_year(year)
-            self.LOGGER.debug(
-                f'Time = {datetime.datetime.today().strftime("%H:%M:%S")}'
+        if self.nvd_type == "api":
+            self.LOGGER.debug("Populating database from NVD API")
+            self.populate_cve_list(
+                self.all_cve_entries,
+                cursor,
+                insert_severity,
+                insert_cve_range,
+                del_cve_range,
             )
-            for cve_item in cve_data["CVE_Items"]:
-                # the information we want:
-                # CVE ID, Severity, Score ->
-                # affected {Vendor(s), Product(s), Version(s)}
-                cve = {
-                    "ID": cve_item["cve"]["CVE_data_meta"]["ID"],
-                    "description": cve_item["cve"]["description"]["description_data"][
-                        0
-                    ]["value"],
-                    "severity": "unknown",
-                    "score": "unknown",
-                    "CVSS_version": "unknown",
-                }
-                # Get CVSSv3 or CVSSv2 score for output.
-                # Details are left as an exercise to the user.
-                if "baseMetricV3" in cve_item["impact"]:
-                    cve["severity"] = cve_item["impact"]["baseMetricV3"]["cvssV3"][
-                        "baseSeverity"
-                    ]
-                    cve["score"] = cve_item["impact"]["baseMetricV3"]["cvssV3"][
-                        "baseScore"
-                    ]
-                    cve["CVSS_version"] = 3
-                elif "baseMetricV2" in cve_item["impact"]:
-                    cve["severity"] = cve_item["impact"]["baseMetricV2"]["severity"]
-                    cve["score"] = cve_item["impact"]["baseMetricV2"]["cvssV2"][
-                        "baseScore"
-                    ]
-                    cve["CVSS_version"] = 2
+        else:
+            # error_mode.value will only be greater than 1 if quiet mode.
+            if self.error_mode.value > 1:
+                years = track(self.nvd_years(), description="Updating CVEs from NVD...")
+            else:
+                years = self.nvd_years()
 
-                # self.LOGGER.debug(
-                #    "Severity: {} ({}) v{}".format(
-                #        CVE["severity"], CVE["score"], CVE["CVSS_version"]
-                #    )
-                # )
-
-                cursor.execute(
+            for year in years:
+                cve_data = self.load_nvd_year(year)
+                self.LOGGER.debug(
+                    f'Time = {datetime.datetime.today().strftime("%H:%M:%S")}'
+                )
+                self.populate_cve_list(
+                    cve_data["CVE_Items"],
+                    cursor,
                     insert_severity,
-                    [
-                        cve["ID"],
-                        cve["severity"],
-                        cve["description"],
-                        cve["score"],
-                        cve["CVSS_version"],
-                    ],
-                )
-
-                # Delete any old range entries for this CVE_number
-                cursor.execute(del_cve_range, (cve["ID"],))
-
-                # walk the nodes with version data
-                # return list of versions
-                affects_list = []
-                if "configurations" in cve_item:
-                    for node in cve_item["configurations"]["nodes"]:
-                        # self.LOGGER.debug("NODE: {}".format(node))
-                        affects_list.extend(self.parse_node(node))
-                        if "children" in node:
-                            for child in node["children"]:
-                                affects_list.extend(self.parse_node(child))
-                # self.LOGGER.debug("Affects: {}".format(affects_list))
-                cursor.executemany(
                     insert_cve_range,
-                    [
-                        (
-                            cve["ID"],
-                            affected["vendor"],
-                            affected["product"],
-                            affected["version"],
-                            affected["versionStartIncluding"],
-                            affected["versionStartExcluding"],
-                            affected["versionEndIncluding"],
-                            affected["versionEndExcluding"],
-                        )
-                        for affected in affects_list
-                    ],
+                    del_cve_range,
                 )
-            self.connection.commit()
+        self.connection.commit()
 
         # supplemental data gets added here
         self.supplement_curl()
 
         self.db_close()
 
+    def populate_cve_list(
+        self, all_cve_list, cursor, insert_severity, insert_cve_range, del_cve_range
+    ):
+        """Populate the cve_list with the CVEs from the JSON"""
+        for cve_item in all_cve_list:
+            # the information we want:
+            # CVE ID, Severity, Score ->
+            # affected {Vendor(s), Product(s), Version(s)}
+            cve = {
+                "ID": cve_item["cve"]["CVE_data_meta"]["ID"],
+                "description": cve_item["cve"]["description"]["description_data"][0][
+                    "value"
+                ],
+                "severity": "unknown",
+                "score": "unknown",
+                "CVSS_version": "unknown",
+                "CVSS_vector": "unknown",
+            }
+            if cve["description"].startswith("** REJECT **"):
+                # Skip this CVE if it's marked as 'REJECT'
+                continue
+
+            # Get CVSSv3 or CVSSv2 score for output.
+            # Details are left as an exercise to the user.
+            if "baseMetricV3" in cve_item["impact"]:
+                cve["severity"] = cve_item["impact"]["baseMetricV3"]["cvssV3"][
+                    "baseSeverity"
+                ]
+                cve["score"] = cve_item["impact"]["baseMetricV3"]["cvssV3"]["baseScore"]
+                cve["CVSS_vector"] = cve_item["impact"]["baseMetricV3"]["cvssV3"][
+                    "vectorString"
+                ]
+                cve["CVSS_version"] = 3
+            elif "baseMetricV2" in cve_item["impact"]:
+                cve["severity"] = cve_item["impact"]["baseMetricV2"]["severity"]
+                cve["score"] = cve_item["impact"]["baseMetricV2"]["cvssV2"]["baseScore"]
+                cve["CVSS_vector"] = cve_item["impact"]["baseMetricV2"]["cvssV2"][
+                    "vectorString"
+                ]
+                cve["CVSS_version"] = 2
+
+            # self.LOGGER.debug(
+            #    "Severity: {} ({}) v{}".format(
+            #        CVE["severity"], CVE["score"], CVE["CVSS_version"]
+            #    )
+            # )
+
+            cursor.execute(
+                insert_severity,
+                [
+                    cve["ID"],
+                    cve["severity"],
+                    cve["description"],
+                    cve["score"],
+                    cve["CVSS_version"],
+                    cve["CVSS_vector"],
+                ],
+            )
+
+            # Delete any old range entries for this CVE_number
+            cursor.execute(del_cve_range, (cve["ID"],))
+
+            # walk the nodes with version data
+            # return list of versions
+            affects_list = []
+            if "configurations" in cve_item:
+                for node in cve_item["configurations"]["nodes"]:
+                    # self.LOGGER.debug("NODE: {}".format(node))
+                    affects_list.extend(self.parse_node(node))
+                    if "children" in node:
+                        for child in node["children"]:
+                            affects_list.extend(self.parse_node(child))
+            # self.LOGGER.debug("Affects: {}".format(affects_list))
+            cursor.executemany(
+                insert_cve_range,
+                [
+                    (
+                        cve["ID"],
+                        affected["vendor"],
+                        affected["product"],
+                        affected["version"],
+                        affected["versionStartIncluding"],
+                        affected["versionStartExcluding"],
+                        affected["versionEndIncluding"],
+                        affected["versionEndExcluding"],
+                    )
+                    for affected in affects_list
+                ],
+            )
+
     def parse_node(self, node):
         affects_list = []
         if "cpe_match" in node:
@@ -642,6 +718,47 @@ class CVEDB:
             self.LOGGER.warning(f"Deleting old cachedir {OLD_CACHE_DIR}")
             shutil.rmtree(OLD_CACHE_DIR)
 
+    def get_vendor_product_pairs(self, package_names):
+        """
+        Fetches vendor from the database for packages that doesn't have vendor info for Package List Parser Utility and Universal Python package checker.
+        """
+        self.db_open()
+        cursor = self.connection.cursor()
+        vendor_package_pairs = []
+        query = """
+        SELECT DISTINCT vendor FROM cve_range
+        WHERE product=?
+        """
+
+        # For python package checkers we don't need the progress bar running
+        if type(package_names) != list:
+            cursor.execute(query, [package_names])
+            vendors = list(map(lambda x: x[0], cursor.fetchall()))
+            for vendor in vendors:
+                if vendor != "":
+                    vendor_package_pairs.append(
+                        {
+                            "vendor": vendor,
+                            "product": package_names,
+                        }
+                    )
+        else:
+            for package_name in track(
+                package_names, description="Processing the given list...."
+            ):
+                cursor.execute(query, [package_name["name"].lower()])
+                vendors = list(map(lambda x: x[0], cursor.fetchall()))
+                for vendor in vendors:
+                    if vendor != "":
+                        vendor_package_pairs.append(
+                            {
+                                "vendor": vendor,
+                                "product": package_name["name"],
+                            }
+                        )
+        self.db_close()
+        return vendor_package_pairs
+
     def db_open(self):
         """Opens connection to sqlite database."""
         if not self.connection:
@@ -671,7 +788,7 @@ class CVEDB:
     def rollback_cache_backup(self):
         """Rollback the cachedir backup in case anything fails"""
         if os.path.exists(os.path.join(self.backup_cachedir, DBNAME)):
-            self.LOGGER.info(f"Rolling back the cache to its previous state")
+            self.LOGGER.info("Rolling back the cache to its previous state")
             if os.path.exists(self.cachedir):
                 shutil.rmtree(self.cachedir)
             shutil.move(self.backup_cachedir, self.cachedir)
