@@ -13,6 +13,24 @@ from typing import DefaultDict, Dict, List, Union
 from ..util import CVE, CVEData, ProductInfo, Remarks
 
 
+def get_cve_summary(all_cve_data: Dict[ProductInfo, CVEData]) -> Dict[str, int]:
+    """
+    summary: Generate a summary count for the number of CVEs in each severity category
+
+    Args:
+        Dictionary of CVEs
+
+    Returns:
+        Dictoinary containing count of CVEs in each severity category
+    """
+    summary = {"CRITICAL": 0, "HIGH": 0, "MEDIUM": 0, "LOW": 0}
+    for cve_data in all_cve_data.values():
+        for s in summary.keys():
+            summary[s] += sum(cve.severity == s for cve in cve_data["cves"])
+
+    return summary
+
+
 def generate_filename(extension: str, prefix: str = "output") -> str:
     """
     summary: Generate a unique filename with extension provided.
@@ -67,6 +85,7 @@ def format_output(all_cve_data: Dict[ProductInfo, CVEData]) -> List[Dict[str, st
                     "severity": cve.severity,
                     "score": str(cve.score),
                     "cvss_version": str(cve.cvss_version),
+                    "cvss_vector": cve.cvss_vector,
                     "paths": ", ".join(cve_data["paths"]),
                     "remarks": cve.remarks.name,
                     "comments": cve.comments,
@@ -174,6 +193,7 @@ def group_cve_by_remark(
                 "cve_number": cve.cve_number,
                 "severity": cve.severity,
                 "description": cve.description,
+                "vector": cve.cvss_vector,
             }
         )
     return cve_by_remarks
