@@ -1,8 +1,6 @@
 # Copyright (C) 2021 Intel Corporation
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-#!/usr/bin/python3
-
 """
 These are the customized strings and file classes, by doing this
 the tool is able to support other operating systems like Windows
@@ -20,7 +18,7 @@ class Strings:
 
     def __init__(self, filename=""):
         self.filename = filename
-        self.output = [""]
+        self.output = ""
 
     async def aio_parse(self):
         async with FileIO(self.filename, "rb") as f:
@@ -31,7 +29,7 @@ class Strings:
                     if char in Strings.PRINTABLE:
                         tmp.append(chr(char))
                     elif tmp:
-                        self.output.append("".join(tmp))
+                        self.output += "".join(tmp) + "\n"
                         tmp = []
         return self.output
 
