@@ -39,4 +39,4 @@ async def test_aio_run_command_success():
 async def test_aio_run_command_returncode_non_zero():
     with unittest.mock.patch("asyncio.create_subprocess_exec", new=mkexec(1)):
         with pytest.raises(subprocess.CalledProcessError):
-            await aio_run_command(("echo", "hello"))
+            await aio_run_command(("echo", "hello"), process_can_fail=False)
