@@ -4,7 +4,6 @@
 """
 CVE-bin-tool CLI tests
 """
-import json
 import logging
 import os
 import tempfile
@@ -23,6 +22,7 @@ import pytest
 
 from cve_bin_tool.cli import main
 from cve_bin_tool.cvedb import DISK_LOCATION_DEFAULT
+from cve_bin_tool.error_handler import ERROR_CODES, InsufficientArgs
 from cve_bin_tool.extractor import Extractor
 from cve_bin_tool.version_scanner import VersionScanner
 
@@ -63,20 +63,17 @@ class TestCLI(TempDirTest):
     def test_extract_bad_zip_messages(self, caplog):
         """Test that bad zip files are logged as extraction failed, but
         bad exe files produce no such message"""
-        BAD_EXE_FILE = os.path.join(
-            os.path.join(os.path.abspath(os.path.dirname(__file__)), "assets"),
-            "empty-file.exe",
-        )
+        bad_exe_file = os.path.join(self.tempdir, "empty-file.exe")
+        # creates an empty, invalid .exe test file
+        open(bad_exe_file, "w").close()
         with caplog.at_level(logging.WARNING):
-            main(["cve-bin-tool", BAD_EXE_FILE])
+            main(["cve-bin-tool", bad_exe_file])
         assert "Failure extracting" not in caplog.text
 
-        BAD_ZIP_FILE = os.path.join(
-            os.path.join(os.path.abspath(os.path.dirname(__file__)), "assets"),
-            "empty-file.zip",
-        )
+        bad_zip_file = os.path.join(self.tempdir, "empty-file.zip")
+        open(bad_zip_file, "w").close()
         with caplog.at_level(logging.WARNING):
-            main(["cve-bin-tool", BAD_ZIP_FILE])
+            main(["cve-bin-tool", bad_zip_file])
         assert "Failure extracting" in caplog.text
 
     def test_exclude(self, caplog):
@@ -92,46 +89,55 @@ class TestCLI(TempDirTest):
         """Test that the usage returns 0"""
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool"])
-        assert e.value.args[0] == -6
+        assert e.value.args[0] == ERROR_CODES[InsufficientArgs]
 
     def test_invalid_file_or_directory(self):
         """Test behaviour with an invalid file/directory"""
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", "non-existant"])
-        assert e.value.args[0] == -3
+        assert e.value.args[0] == ERROR_CODES[FileNotFoundError]
 
     def test_invalid_parameter(self):
         """Test that invalid parmeters exit with expected error code.
-        ArgParse calls sys.exit(2) for all errors, we've overwritten to -2"""
+        ArgParse calls sys.exit(2) for all errors"""
 
         # no directory specified
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", "--bad-param"])
-        assert e.value.args[0] == -2
+        assert e.value.args[0] == ERROR_CODES[SystemExit]
 
         # bad parameter (but good directory)
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", "--bad-param", self.tempdir])
-        assert e.value.args[0] == -2
+        assert e.value.args[0] == ERROR_CODES[SystemExit]
 
         # worse parameter
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", "--bad-param && cat hi", self.tempdir])
-        assert e.value.args[0] == -2
+        assert e.value.args[0] == ERROR_CODES[SystemExit]
 
         # bad parameter after directory
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", self.tempdir, "--bad-param;cat hi"])
-        assert e.value.args[0] == -2
+        assert e.value.args[0] == ERROR_CODES[SystemExit]
 
     @unittest.skipUnless(LONG_TESTS() > 0, "Skipping long tests")
     def test_update_flags(self):
-        assert main(["cve-bin-tool", "-x", "-u", "never", self.tempdir]) != 0
-        assert main(["cve-bin-tool", "-x", "--update", "daily", self.tempdir]) != 0
-        assert main(["cve-bin-tool", "-x", "-u", "now", self.tempdir]) != 0
+        assert (
+            main(["cve-bin-tool", "-x", "-u", "never", "-n", "json", self.tempdir]) != 0
+        )
+        assert (
+            main(
+                ["cve-bin-tool", "-x", "--update", "daily", "-n", "json", self.tempdir]
+            )
+            != 0
+        )
+        assert (
+            main(["cve-bin-tool", "-x", "-u", "now", "-n", "json", self.tempdir]) != 0
+        )
         with pytest.raises(SystemExit) as e:
-            main(["cve-bin-tool", "-u", "whatever", self.tempdir])
-        assert e.value.args[0] == -2
+            main(["cve-bin-tool", "-u", "whatever", "-n", "json", self.tempdir])
+        assert e.value.args[0] == ERROR_CODES[SystemExit]
 
     @staticmethod
     def check_exclude_log(caplog, exclude_path, checkers):
@@ -198,7 +204,7 @@ class TestCLI(TempDirTest):
         test_path = os.path.join(os.path.abspath(os.path.dirname(__file__)), "csv")
 
         with caplog.at_level(logging.INFO):
-            main(["cve-bin-tool", "-u", "never", test_path])
+            main(["cve-bin-tool", "-u", "never", "-n", "json", test_path])
         assert (
             "cve_bin_tool",
             logging.WARNING,
@@ -206,21 +212,23 @@ class TestCLI(TempDirTest):
         ) in caplog.record_tuples
         caplog.clear()
 
-        with caplog.at_level(logging.INFO):
-            main(["cve-bin-tool", "-u", "daily", test_path])
+        with caplog.at_level(logging.DEBUG):
+            main(
+                ["cve-bin-tool", "-l", "debug", "-u", "daily", "-n", "json", test_path]
+            )
         assert (
             "cve_bin_tool.CVEDB",
             logging.INFO,
             "Using cached CVE data (<24h old). Use -u now to update immediately.",
         ) in caplog.record_tuples or (
             "cve_bin_tool.CVEDB",
-            logging.INFO,
+            logging.DEBUG,
             "Updating CVE data. This will take a few minutes.",
         ) in caplog.record_tuples
         caplog.clear()
 
-        with caplog.at_level(logging.INFO):
-            main(["cve-bin-tool", "-u", "now", test_path])
+        with caplog.at_level(logging.DEBUG):
+            main(["cve-bin-tool", "-l", "debug", "-u", "now", "-n", "json", test_path])
         db_path = DISK_LOCATION_DEFAULT
         assert (
             "cve_bin_tool.CVEDB",
@@ -228,22 +236,24 @@ class TestCLI(TempDirTest):
             f"Updating cachedir {db_path}",
         ) in caplog.record_tuples and (
             "cve_bin_tool.CVEDB",
-            logging.INFO,
+            logging.DEBUG,
             "Updating CVE data. This will take a few minutes.",
         ) in caplog.record_tuples
         caplog.clear()
 
-        with caplog.at_level(logging.INFO):
-            main(["cve-bin-tool", "-u", "latest", test_path])
+        with caplog.at_level(logging.DEBUG):
+            main(
+                ["cve-bin-tool", "-l", "debug", "-u", "latest", "-n", "json", test_path]
+            )
         assert (
             "cve_bin_tool.CVEDB",
-            logging.INFO,
+            logging.DEBUG,
             "Updating CVE data. This will take a few minutes.",
         ) in caplog.record_tuples
         caplog.clear()
 
     def test_unknown_warning(self, caplog):
-        """Test that an "UNKNOWN" file generates a warning"""
+        """Test that an "UNKNOWN" file generates a log (only in debug mode)"""
 
         # build the unknown test file in test/binaries
         with tempfile.NamedTemporaryFile(
@@ -257,8 +267,8 @@ class TestCLI(TempDirTest):
             filename = f.name
 
         # Run against the "unknown" file
-        with caplog.at_level(logging.INFO):
-            main(["cve-bin-tool", filename])
+        with caplog.at_level(logging.DEBUG):
+            main(["cve-bin-tool", filename, "-l", "debug"])
 
         # clean up temporary file.
         os.remove(filename)
@@ -266,7 +276,7 @@ class TestCLI(TempDirTest):
         warnings = [
             record.message
             for record in caplog.records
-            if record.levelname == "WARNING" and record.module == "version_scanner"
+            if record.levelname == "DEBUG" and record.module == "version_scanner"
         ]
         assert len(warnings) > 0, "Unknown version warning didn't get generated"
         assert f"png was detected with version UNKNOWN in file {filename}" in warnings
@@ -310,11 +320,11 @@ class TestCLI(TempDirTest):
             "Checkers: binutils, curl",
         ) in caplog.record_tuples
 
-        # assert only CVEs of curl get reflected. Because other are skipped
+        # assert only CVEs of curl and libcurl get reflected. Because others are skipped
         assert (
             "cve_bin_tool",
             logging.INFO,
-            "There are 1 products with known CVEs detected",
+            "There are 2 products with known CVEs detected",
         ) in caplog.record_tuples
 
         for record in caplog.record_tuples:
@@ -340,11 +350,11 @@ class TestCLI(TempDirTest):
         # Check command line parameters - wrong case
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", "-S", "HIGH", self.tempdir])
-        assert e.value.args[0] == -2
+        assert e.value.args[0] == ERROR_CODES[SystemExit]
         # Check command line parameters - wrong option
         with pytest.raises(SystemExit) as e:
             main(["cve-bin-tool", "-S", "ALL", self.tempdir])
-        assert e.value.args[0] == -2
+        assert e.value.args[0] == ERROR_CODES[SystemExit]
 
         my_test_filename = "sevtest.csv"
 
@@ -457,3 +467,24 @@ class TestCLI(TempDirTest):
         if os.path.exists(my_test_filename):
             os.remove(my_test_filename)
         caplog.clear()
+
+    def test_SBOM(self, caplog):
+        # check sbom file option
+        SBOM_PATH = os.path.join(os.path.abspath(os.path.dirname(__file__)), "sbom")
+
+        with caplog.at_level(logging.INFO):
+            main(
+                [
+                    "cve-bin-tool",
+                    "--sbom",
+                    "spdx",
+                    "--sbom-file",
+                    os.path.join(SBOM_PATH, "spdx_test.spdx"),
+                ]
+            )
+        # Verify that one product detected
+        assert (
+            "cve_bin_tool",
+            logging.INFO,
+            "There are 1 products with known CVEs detected",
+        ) in caplog.record_tuples
