@@ -6,13 +6,14 @@ Test to check if condensed downloads are committed
 """
 import importlib
 import subprocess
-from test.test_data import __all__ as all_test_name
+
+from cve_bin_tool.checkers import __all__ as all_test_name
 
 
 # Test to check condensed files are committed according to the package test data of checkers
 def test_condensed_downloads():
     test_data = list(
-        map(lambda x: importlib.import_module(f"test.test_data.{x}"), all_test_name)
+        map(lambda x: importlib.import_module(f"test.test_data.{x}"), all_test_name[2:])
     )
 
     package_names = []
