@@ -15,8 +15,7 @@ class TestConfig:
         "cvss": 0,
         "directory": "test/assets",
         "disable_version_check": False,
-        "exclude": [],
-        "extract": False,
+        "extract": True,
         "format": "console",
         "input_file": "test/csv/triage.csv",
         "log_level": "debug",
