@@ -21,4 +21,16 @@ package_test_data = [
         "product": "freeradius",
         "version": "2.2.10",
     },
+    {
+        "url": "https://ftp.netbsd.org/pub/pkgsrc/packages/NetBSD/aarch64/9.1/All/",
+        "package_name": "freeradius-3.0.21nb3.tgz",
+        "product": "freeradius",
+        "version": "3.0.21",
+    },
+    {
+        "url": "http://ftp.br.debian.org/debian/pool/main/f/freeradius/",
+        "package_name": "freeradius_3.0.12+dfsg-5+deb9u1_amd64.deb",
+        "product": "freeradius",
+        "version": "3.0.12",
+    },
 ]
