@@ -17,4 +17,16 @@ package_test_data = [
         "product": "irssi",
         "version": "0.8.16",
     },
+    {
+        "url": "https://ftp.netbsd.org/pub/pkgsrc/packages/NetBSD/amd64/9.1/All/",
+        "package_name": "irssi-1.2.3nb1.tgz",
+        "product": "irssi",
+        "version": "1.2.3",
+    },
+    {
+        "url": "http://ftp.br.debian.org/debian/pool/main/i/irssi/",
+        "package_name": "irssi_1.0.7-1~deb9u1_amd64.deb",
+        "product": "irssi",
+        "version": "1.0.7",
+    },
 ]
