@@ -21,4 +21,16 @@ package_test_data = [
         "product": "libarchive",
         "version": "3.1.2",
     },
+    {
+        "url": "http://ftp.br.debian.org/debian/pool/main/liba/libarchive/",
+        "package_name": "libarchive13_3.4.3-2+b1_amd64.deb",
+        "product": "libarchive",
+        "version": "3.4.3",
+    },
+    {
+        "url": "https://ftp.netbsd.org/pub/pkgsrc/packages/NetBSD/amd64/8.2/All/",
+        "package_name": "libarchive-3.4.3.tgz",
+        "product": "libarchive",
+        "version": "3.4.3",
+    },
 ]
