@@ -21,9 +21,15 @@ package_test_data = [
         "version": "2.70.0",
     },
     {
-        "url": "http://mirror.centos.org/centos/8/BaseOS/aarch64/os/Packages/",
-        "package_name": "libsoup-2.62.3-2.el8.aarch64.rpm",
+        "url": "http://ports.ubuntu.com/pool/main/libs/libsoup2.4/",
+        "package_name": "libsoup2.4-1_2.72.0-3_arm64.deb",
         "product": "libsoup",
-        "version": "2.62.3",
+        "version": "2.72.0",
+    },
+    {
+        "url": "https://ftp.netbsd.org/pub/pkgsrc/packages/NetBSD/amd64/9.1/All/",
+        "package_name": "libsoup-2.70.0nb4.tgz",
+        "product": "libsoup",
+        "version": "2.70.0",
     },
 ]
