@@ -26,4 +26,16 @@ package_test_data = [
         "product": "libssh2",
         "version": "1.8.0",
     },
+    {
+        "url": "http://ftp.br.debian.org/debian/pool/main/libs/libssh2/",
+        "package_name": "libssh2-1_1.9.0-3_amd64.deb",
+        "product": "libssh2",
+        "version": "1.9.0",
+    },
+    {
+        "url": "https://ftp.netbsd.org/pub/pkgsrc/packages/NetBSD/amd64/9.1/All/",
+        "package_name": "libssh2-1.9.0nb1.tgz",
+        "product": "libssh2",
+        "version": "1.9.0",
+    },
 ]
