@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "libpng",
@@ -18,7 +21,7 @@ package_test_data = [
     },
     {
         "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
-        "package_name": "libpng-1.5.13-7.el7_2.x86_64.rpm",
+        "package_name": "libpng-1.5.13-8.el7.x86_64.rpm",
         "product": "libpng",
         "version": "1.5.13",
     },
