@@ -27,10 +27,17 @@ package_test_data = [
         "product": "systemd",
         "version": "244",
     },
-    # {
-    #    "url": "https://rpmfind.net/linux/fedora/linux/releases/33/Everything/x86_64/os/Packages/s/",
-    #    "package_name": "systemd-246.6-3.fc33.i686.rpm",
-    #    "product": "systemd",
-    #    "version": "243",
-    # },
+    {
+        "url": "https://rpmfind.net/linux/fedora/linux/releases/33/Everything/x86_64/os/Packages/s/",
+        "package_name": "systemd-246.6-3.fc33.i686.rpm",
+        "product": "systemd",
+        "version": "246",
+    },
+    # Below is the package with multiple systemd versions present
+    {
+        "url": "https://github.com/intel/cve-bin-tool/files/6452330/",
+        "package_name": "libsystemd.tar.gz",
+        "product": "systemd",
+        "version": "246",
+    },
 ]
