@@ -4,12 +4,9 @@
 """
 Resource definitions and helper utilities for tests.
 """
-import asyncio
 import os
 import shutil
-import sys
 import tempfile
-import unittest
 from urllib.request import urlopen
 
 import pytest
